# Artifidial DJ software

ARDJ is a software to operate an internet radio in automatic mode.
It integrates with ices/ezstream, communicates with admins and listeners using the XMPP protocol (Jabber), can send messages to twitter, download music from Last.fm and Jamendo, and more.

Distributed under the GNU GPL.


## Links

- Mercurial repo: <http://bitbucket.org/umonkey/ardj>
- Online docs: <https://bitbucket.org/umonkey/ardj/src/default/doc/>
- PIP repo: <https://pypi.python.org/pypi/ardj>
- Example running station: <http://tmradio.net/>


## Authors

Parts of this software were written by:

- Justin Forest (hex@umonkey.net)
- Hakimov Irik (hakimovis@gmail.com)
- Kaener Vora (k43n3r@gmail.com)
